==> apache-pulsar-3.0.14-src.tar.gz: apache-pulsar-3.0.14-src/pulsar-broker/src/test/java/org/apache/pulsar/broker/service/persistent/BrokerServicePersistInternalMethodInvoker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker.service.persistent;

import java.util.concurrent.TimeUnit;
import org.apache.bookkeeper.mledger.impl.PositionImpl;
import org.awaitility.Awaitility;

public class BrokerServicePersistInternalMethodInvoker {

    public static void replicatorReadMoreEntries(GeoPersistentReplicator replicator) {
        replicator.readMoreEntries();
    }

    public static void ensureNoBacklogByInflightTask(PersistentReplicator replicator) {
        Awaitility.await().atMost(20, TimeUnit.SECONDS).until(() -> {
            synchronized (replicator.inFlightTasks) {
                for (PersistentReplicator.InFlightTask task : replicator.inFlightTasks) {
                    if (task.readPos.compareTo(
                            (PositionImpl) replicator.cursor.getManagedLedger().getLastConfirmedEntry()) >= 0) {
                        continue;
                    }
                    if (!task.isDone()) {
                        return false;
                    }
                }
            }
            return true;
        });
    }
}

==> apache-pulsar-4.1.2-src.tar.gz: apache-pulsar-4.1.2-src/pulsar-broker/src/test/java/org/apache/pulsar/broker/service/persistent/BrokerServicePersistInternalMethodInvoker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.broker.service.persistent;

import java.util.concurrent.TimeUnit;
import org.awaitility.Awaitility;

public class BrokerServicePersistInternalMethodInvoker {

    public static void replicatorReadMoreEntries(GeoPersistentReplicator replicator) {
        replicator.readMoreEntries();
    }

    public static void ensureNoBacklogByInflightTask(PersistentReplicator replicator) {
        Awaitility.await().atMost(20, TimeUnit.SECONDS).until(() -> {
            synchronized (replicator.inFlightTasks) {
                for (PersistentReplicator.InFlightTask task : replicator.inFlightTasks) {
                    if (task.readPos.compareTo(replicator.cursor.getManagedLedger().getLastConfirmedEntry()) >= 0) {
                        continue;
                    }
                    if (!task.isDone()) {
                        return false;
                    }
                }
            }
            return true;
        });
    }
}
